@@ -880,11 +880,12 @@ def doconce_exercise_output(
     language = locale_dict['language']
     Solution = locale_dict[language]['Solution']
     if solution_header == '__Solution.__':
-        solution_header = locale_dict[language]['__Solution.__']
+        solution_header = '__{0}.__'.format(locale_dict[language]['Solution'])
     if answer_header == '__Answer.__':
-        answer_header = locale_dict[language]['__Answer.__']
+        answer_header = '__{0}.__'.format(locale_dict[language]['Answer'])
     if hint_header == '__Hint.__':
-        hint_header = locale_dict[language]['__Hint.__']
+        hint_header = '__{0}.__'.format(locale_dict[language]['Hint'])
+
 
     # Store solutions in a separate string
     has_solutions = False
@@ -1221,7 +1222,7 @@ def has_custom_pygments_lexer(name):
     return True
 
 
-def tikz2img(tikz_file, encoding='utf8', tikz_libs=None):
+def tikz2img(tikz_file, encoding='utf8', tikz_libs=None, pgfplots_libs=None):
     dvisvgm_template = r"""
 \documentclass[dvisvgm]{minimal}
 
@@ -1234,6 +1235,9 @@ def tikz2img(tikz_file, encoding='utf8', tikz_libs=None):
 %% TikZ libraries
 %s
 
+%% pgfplots libraries
+%s
+
 \begin{document}
 \noindent
 \input{%s}
@@ -1250,6 +1254,13 @@ def tikz2img(tikz_file, encoding='utf8', tikz_libs=None):
         # Error
         raise Exception("TikZ libraries is not a list!")
 
+    if pgfplots_libs is None:
+        pgfplots_libs = ""
+    elif isinstance(pgfplots_libs, list):
+        pgfplots_libs = r"\usepgfplotslibrary{%s}" % (', '.join(pgfplots_libs))
+    else:
+        # Error
+        raise Exception("pgfplots libraries is not a list!")
     # create temporary directory
     fig_dir = os.path.dirname(tikz_file)
     tmp_dir = os.path.join(fig_dir, 'tmp_tikz_rendering')
@@ -1267,7 +1278,7 @@ def tikz2img(tikz_file, encoding='utf8', tikz_libs=None):
 
 
     # wrap tikz in TeX file
-    tex_content = dvisvgm_template % (encoding, tikz_libs, tikz_file)
+    tex_content = dvisvgm_template % (encoding, tikz_libs, pgfplots_libs, tikz_file)
     #print tex_content
 
     with open(tex_file, 'w') as f:
